/*--------------------------------------------------------------------------
| FILE NAME: Strings.h
|
| DOCUMENT: [236.1]
|
| PURPOSE: To provide interface for control of zero-terminated strings.
|
| DESCRIPTION:  A string looks like this:
|
|                [------------------------0]
|                 \                        \_ StringTerminator field
|                  ----StringData field
|
|         Field       Offset      Length      Description
|     -------------------------------------------------------------------
|     StringData        0         any     The data which may be any
|                                         byte value except 0.
|     StringTerminator  any       1       a 0 byte to mark end of string
|     -------------------------------------------------------------------     
|
| NOTE: See 'BString.c' for strings prefixed with a count byte.
|       See 'Parse.h' for string parsing functions.
|
| HISTORY: 02.01.89 by Lee Malone
|          02.15.93 from xstring.h.
--------------------------------------------------------------------------*/
    
#ifndef    _STRINGS_H_
#define    _STRINGS_H_

#include <DataSize.h>

/* ------------------------ PROTOTYPES -------------------------------- */

Nothing         AppendString(AddressOfString, AddressOfString);
Nothing         AppendStrings(AddressOfString, AddressOfString, ...);
Comparison      CompareStrings(AddressOfString, AddressOfString);
Nothing         ConvertStringToLowerCase(AddressOfString);
Nothing         ConvertStringToUpperCase(AddressOfString);
Nothing         CopyString(AddressOfString, AddressOfString);
Quad            CountString(AddressOfString);
AddressOfString FindLastByteInString(AddressOfString);
Nothing         InsertString(AddressOfString, AddressOfString, Quad);
Nothing         ReplaceBytesInString(AddressOfString, Pair, Pair);


#endif
